@@ -64,10 +64,18 @@ my %ALIAS_MAP =
   # Standard Java VM Attributes
   # Memory  
   MEMORY_HEAP => [ "Heap memory usage, multiple values", [ "java.lang:type=Memory", "HeapMemoryUsage" ]],
-  MEMORY_HEAP_USED => [ "Usedo heap memory", [ "java.lang:type=Memory", "HeapMemoryUsage", "used" ]],
+  MEMORY_HEAP_USED => [ "Used heap memory", [ "java.lang:type=Memory", "HeapMemoryUsage", "used" ]],
   MEMORY_HEAP_INIT => [ "Initially allocated heap memory", [ "java.lang:type=Memory", "HeapMemoryUsage", "init" ]],
-  MEMORY_HEAP_COMITTED => [ "Committed heap memory", [ "java.lang:type=Memory", "HeapMemoryUsage", "committed" ]],
-  MEMORY_HEAP_MAX => [ "Committed heap memory", [ "java.lang:type=Memory", "HeapMemoryUsage", "max" ]],
+  MEMORY_HEAP_COMITTED => [ "Committed heap memory. That's the memory currently available for this JVM", [ "java.lang:type=Memory", "HeapMemoryUsage", "committed" ]],
+  MEMORY_HEAP_MAX => [ "Maximum available heap memory", [ "java.lang:type=Memory", "HeapMemoryUsage", "max" ]],
+
+  MEMORY_NONHEAP => [ "Non-Heap memory usage, multiple values", [ "java.lang:type=Memory", "NonHeapMemoryUsage" ]],
+  MEMORY_NONHEAP_USED => [ "Used non-heap memory (like a 'method area')", [ "java.lang:type=Memory", "NonHeapMemoryUsage", "used" ]],
+  MEMORY_NONHEAP_INIT => [ "Initially allocated non-heap memory", [ "java.lang:type=Memory", "NonHeapMemoryUsage", "init" ]],
+  MEMORY_NONHEAP_COMITTED => [ "Committed non-heap memory", [ "java.lang:type=Memory", "NonHeapMemoryUsage", "committed" ]],
+  MEMORY_NONHEAP_MAX => [ "Maximum available non-heap memory", [ "java.lang:type=Memory", "NonHeapMemoryUsage", "max" ]],
+
+  MEMORY_VERBOSE => [ "Switch on/off verbose messages concerning the garbage collector", ["java.lang:type=Memory", "Verbose"]],
 
   # Class loading
   CL_LOADED => [ "Number of currently loaded classes", [ "java.lang:type=ClassLoading", "LoadedClassCount"]],
@@ -76,20 +84,20 @@ my %ALIAS_MAP =
   
   # Threads
   THREAD_COUNT => ["Active threads in the system", [ "java.lang:type=Threading", "ThreadCount"]],
-  THREAD_COUNT_PEAK => ["Peak count of active threads in the system", [ "java.lang:type=Threading", "PeakThreadCount"]],
+  THREAD_COUNT_PEAK => ["Peak thread count", [ "java.lang:type=Threading", "PeakThreadCount"]],
   THREAD_COUNT_STARTED => ["Count of threads started since system start", [ "java.lang:type=Threading", "TotalStartedThreadCount"]],
   THREAD_COUNT_DAEMON => ["Count of threads marked as daemons in the system", [ "java.lang:type=Threading", "DaemonThreadCount"]],
   
   # Operating System
-  OS_MEMORY_FREE_PHYSICAL => ["The amount of free physical memory for the OS", [ "java.lang:type=OperatingSystem", "FreePhysicalMemorySize"]],
-  OS_MEMORY_FREE_SWAP => ["The amount of free swap space for the OS", [ "java.lang:type=OperatingSystem", "FreeSwapSpaceSize"]],
-  OS_MEMORY_TOTAL_PHYSICAL => ["The amount of total physical memory for the OS", [ "java.lang:type=OperatingSystem", "TotalPhysicalMemorySize"]],
-  OS_MEMORY_TOTAL_SWAP => ["The amount of total swap memory available", [ "java.lang:type=OperatingSystem", "TotalSwapSpaceSize"]],
+  OS_MEMORY_PHYSICAL_FREE => ["The amount of free physical memory for the OS", [ "java.lang:type=OperatingSystem", "FreePhysicalMemorySize"]],
+  OS_MEMORY_PHYSICAL_TOTAL => ["The amount of total physical memory for the OS", [ "java.lang:type=OperatingSystem", "TotalPhysicalMemorySize"]],
+  OS_MEMORY_SWAP_FREE => ["The amount of free swap space for the OS", [ "java.lang:type=OperatingSystem", "FreeSwapSpaceSize"]],
+  OS_MEMORY_SWAP_TOTAL => ["The amount of total swap memory available", [ "java.lang:type=OperatingSystem", "TotalSwapSpaceSize"]],
   OS_MEMORY_VIRTUAL => ["Size of virtual memory used by this process", [ "java.lang:type=OperatingSystem", "CommittedVirtualMemorySize"]],
-  OS_FILE_OPEN_DESC => ["Number of open file descriptors", [ "java.lang:type=OperatingSystem", "OpenFileDescriptorCount"]],
-  OS_FILE_MAX_DESC => ["Maximum number of open file descriptors", [ "java.lang:type=OperatingSystem", "MaxFileDescriptorCount"]],
+  OS_FILE_DESC_OPEN => ["Number of open file descriptors", [ "java.lang:type=OperatingSystem", "OpenFileDescriptorCount"]],
+  OS_FILE_DESC_MAX => ["Maximum number of open file descriptors", [ "java.lang:type=OperatingSystem", "MaxFileDescriptorCount"]],
   OS_CPU_TIME => ["The cpu time used by this process", [ "java.lang:type=OperatingSystem", "ProcessCpuTime"]],
-  OS_INFO_PROCESSORS => ["Numer of processors", [ "java.lang:type=OperatingSystem", "AvailableProcessors"]],
+  OS_INFO_PROCESSORS => ["Number of processors", [ "java.lang:type=OperatingSystem", "AvailableProcessors"]],
   OS_INFO_ARCH => ["Architecture", [ "java.lang:type=OperatingSystem", "Arch"]],
   OS_INFO_NAME => ["Operating system name", [ "java.lang:type=OperatingSystem", "Name"]],
   OS_INFO_VERSION => ["Operating system version", [ "java.lang:type=OperatingSystem", "Version"]],
@@ -106,8 +114,14 @@ my %ALIAS_MAP =
   RUNTIME_BOOTCLASSPATH => ["Bootclasspath", [ "java.lang:type=Runtime", "BootClassPath"]],
   RUNTIME_LIBRARY_PATH => ["The LD_LIBRARY_PATH", [ "java.lang:type=Runtime", "LibraryPath"]],
   RUNTIME_NAME => ["Name of the runtime", [ "java.lang:type=Runtime", "Name"]],
+
+  # Jmx4Perl
+  JMX4PERL_HISTORY_SIZE => [ "Size of the history of all attributes and operations in bytes" , ["jmx4perl:type=Config","HistorySize"]],
+  JMX4PERL_HISTORY_MAX_ENTRIES => [ "Maximum number of entries per attribute/operation possible" , ["jmx4perl:type=Config","HistoryMaxEntries"]],
+  JMX4PERL_DEBUG => [ "Switch on/off debugging by setting this boolean" , ["jmx4perl:type=Config","Debug"]],
+  JMX4PERL_DEBUG_MAX_ENTRIES => [ "Maximum number of entries for storing debug info" , ["jmx4perl:type=Config","MaxDebugEntries"]],
  },
-   
+
    operation  => 
  {
   # Memory
@@ -116,7 +130,14 @@ my %ALIAS_MAP =
   # Threads
   THREAD_DEADLOCKED => [ "Find cycles of threads that are in deadlock waiting to acquire object monitors", [ "java.lang:type=Threading", "findMonitorDeadlockedThreads"]],
   # TODO: Check for a default
-  THREAD_DUMP => [ "Create a thread dump" ]
+  THREAD_DUMP => [ "Create a thread dump" ],
+
+  # Jmx4Perl
+  JMX4PERL_HISTORY_MAX_ATTRIBUTE => [ "Set the size of the history for a specific attribute" , ["jmx4perl:type=Config","setHistoryEntriesForAttribute"]],
+  JMX4PERL_HISTORY_MAX_OPERATION => [ "Set the size of the history for a specific operation" , ["jmx4perl:type=Config","setHistoryEntriesForOperation"]],
+  JMX4PERL_HISTORY_RESET => [ "Reset the history for all attributes and operations" , ["jmx4perl:type=Config","resetHistoryEntries"]],
+  JMX4PERL_DEBUG_INFO => [ "Print out latest debug info", ["jmx4perl:type=Config","debugInfo"]],
+  JMX4PERL_SERVER_INFO => [ "Show information about registered MBeanServers", ["jmx4perl:type=Config","mBeanServerInfo"]]
  });
 
 my %NAME_TO_ALIAS_MAP;
@@ -215,29 +236,45 @@ outdated, to get the current one, use
  CL_LOADED                      attr Number of currently loaded classes
  CL_TOTAL                       attr Number of classes loaded in total
  CL_UNLOADED                    attr Number of unloaded classes
+ JMX4PERL_DEBUG                 attr Switch on/off debugging by setting this boolean
+ JMX4PERL_DEBUG_INFO            oper Print out latest debug info
+ JMX4PERL_DEBUG_MAX_ENTRIES     attr Maximum number of entries for storing debug info
+ JMX4PERL_HISTORY_MAX_ATTRIBUTE oper Set the size of the history for a specific attribute
+ JMX4PERL_HISTORY_MAX_ENTRIES   attr Maximum number of entries per attribute/operation possible
+ JMX4PERL_HISTORY_MAX_OPERATION oper Set the size of the history for a specific operation
+ JMX4PERL_HISTORY_RESET         oper Reset the history for all attributes and operations
+ JMX4PERL_HISTORY_SIZE          attr Size of the history of all attributes and operations in bytes
+ JMX4PERL_SERVER_INFO           oper Show information about registered MBeanServers
  MEMORY_GC                      oper Run a garbage collection
  MEMORY_HEAP                    attr Heap memory usage, multiple values
- MEMORY_HEAP_COMITTED           attr Committed heap memory
+ MEMORY_HEAP_COMITTED           attr Committed heap memory. That's the memory currently available for this JVM
  MEMORY_HEAP_INIT               attr Initially allocated heap memory
- MEMORY_HEAP_USED               attr User heap memory
+ MEMORY_HEAP_MAX                attr Maximum available heap memory
+ MEMORY_HEAP_USED               attr Used heap memory
+ MEMORY_NONHEAP                 attr Non-Heap memory usage, multiple values
+ MEMORY_NONHEAP_COMITTED        attr Committed non-heap memory
+ MEMORY_NONHEAP_INIT            attr Initially allocated non-heap memory
+ MEMORY_NONHEAP_MAX             attr Maximum available non-heap memory
+ MEMORY_NONHEAP_USED            attr Used non-heap memory (like a 'method area')
+ MEMORY_VERBOSE                 attr Switch on/off verbose messages concerning the garbage collector
  OS_CPU_TIME                    attr The cpu time used by this process
- OS_FILE_MAX_DESC               attr Maximum number of open file descriptors
- OS_FILE_OPEN_DESC              attr Number of open file descriptors
+ OS_FILE_DESC_MAX               attr Maximum number of open file descriptors
+ OS_FILE_DESC_OPEN              attr Number of open file descriptors
  OS_INFO_ARCH                   attr Architecture
  OS_INFO_NAME                   attr Operating system name
- OS_INFO_PROCESSORS             attr Numer of processors
+ OS_INFO_PROCESSORS             attr Number of processors
  OS_INFO_VERSION                attr Operating system version
- OS_MEMORY_FREE_PHYSICAL        attr The amount of free physical memory for the OS
- OS_MEMORY_FREE_SWAP            attr The amount of free swap space for the OS
- OS_MEMORY_TOTAL_PHYSICAL       attr The amount of total physical memory for the OS
- OS_MEMORY_TOTAL_SWAP           attr The amount of total swap memory available
+ OS_MEMORY_PHYSICAL_FREE        attr The amount of free physical memory for the OS
+ OS_MEMORY_PHYSICAL_TOTAL       attr The amount of total physical memory for the OS
+ OS_MEMORY_SWAP_FREE            attr The amount of free swap space for the OS
+ OS_MEMORY_SWAP_TOTAL           attr The amount of total swap memory available
  OS_MEMORY_VIRTUAL              attr Size of virtual memory used by this process
  RUNTIME_ARGUMENTS              attr Arguments when starting the JVM
  RUNTIME_BOOTCLASSPATH          attr Bootclasspath
  RUNTIME_CLASSPATH              attr Classpath
  RUNTIME_LIBRARY_PATH           attr The LD_LIBRARY_PATH
  RUNTIME_NAME                   attr Name of the runtime
- RUNTIME_STARTIME               attr Time when starting the JVM
+ RUNTIME_STARTTIME              attr Time when starting the JVM
  RUNTIME_SYSTEM_PROPERTIES      attr System properties
  RUNTIME_UPTIME                 attr Total uptime of JVM
  RUNTIME_VM_NAME                attr Name of JVM
@@ -249,7 +286,7 @@ outdated, to get the current one, use
  SERVER_VERSION                 attr Version of application server
  THREAD_COUNT                   attr Active threads in the system
  THREAD_COUNT_DAEMON            attr Count of threads marked as daemons in the system
- THREAD_COUNT_PEAK              attr Peak count of active threads in the system
+ THREAD_COUNT_PEAK              attr Peak thread count
  THREAD_COUNT_STARTED           attr Count of threads started since system start
  THREAD_DEADLOCKED              oper Find cycles of threads that are in deadlock waiting to acquire object monitors
  THREAD_DUMP                    oper Create a thread dump
